@@ -10,10 +10,10 @@ def save(*args, **kwargs):
 
 
 def pickle_load(path):
-    with open(path, 'rb') as f:
+    with open(path, "rb") as f:
         return pickle.load(f)
 
 
 def pickle_save(o, path):
-    with open(path, 'wb') as f:
+    with open(path, "wb") as f:
         pickle.dump(o, f)
