@@ -31,29 +31,58 @@ class Tee(object):
     RAISE = "raise"
     EXIT = "exit"
 
-    def __init__(self, tee_filename, behavior=RAISE):
+    def __init__(
+        self,
+        tee_fil=None,
+        tee_filename=None,
+        stdout=None,
+        behavior=RAISE,
+        auto_flush=True,
+    ):
+        if stdout is not None:
+            self.stdout = stdout
+        else:
+            self.stdout = sys.stdout
+        self.auto_flush = auto_flush
+
         self.behavior = behavior.lower()
         assert self.behavior in [
             Tee.RAISE,
             Tee.EXIT,
         ]
-
-        try:
-            self.tee_fil = open(tee_filename, "w")
-        except IOError as ioe:
-            if self.behavior == Tee.RAISE:
-                raise
-            else:
-                exit("Caught IOError: {}".format(repr(ioe)))
-        except Exception as e:
-            if self.behavior == Tee.RAISE:
-                raise
-            else:
-                exit("Caught Exception: {}".format(repr(e)))
+        if tee_fil is not None:
+            self.tee_fil = tee_fil
+        else:
+            try:
+                self.tee_fil = open(tee_filename, "w")
+            except IOError as ioe:
+                if self.behavior == Tee.RAISE:
+                    raise
+                else:
+                    exit("Caught IOError: {}".format(repr(ioe)))
+            except Exception as e:
+                if self.behavior == Tee.RAISE:
+                    raise
+                else:
+                    exit("Caught Exception: {}".format(repr(e)))
 
     def write(self, s):
-        sys.stdout.write(s)
+        self.stdout.write(s)
         self.tee_fil.write(s)
+        if self.auto_flush:
+            self.flush()
+
+    def flush(self):
+        self.stdout.flush()
+        self.tee_fil.flush()
+
+    def __getattr__(self, k):
+        if hasattr(self.stdout, k):
+            return getattr(self.stdout, k)
+
+    @property
+    def isatty(self):
+        return self.stdout.isatty
 
     def writeln(self, s):
         self.write(s + "\n")
@@ -73,7 +102,7 @@ class Tee(object):
                 exit("Caught Exception: {}".format(repr(e)))
 
     def __enter__(self):
-        return self.tee_fil
+        return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
